Welcome to Ensemble Analysis's documentation!
=============================================

.. warning::
    This is still under constrution.

.. toctree::
   :maxdepth: 2
   :caption: Overview:

   readme


.. toctree::
    :maxdepth: 0
    :caption: Documentations:

    documentations

.. toctree::
    :maxdepth: 0
    :caption: Examples:

    examples/examples

.. toctree::
    :maxdepth: 0
    :caption: Contents:

    installation
    contributing
    authors
    history
    
     
Indices and tables
==================
* :ref:`genindex`
* :ref:`search`
